# autowordle

An automatic collector for Wordle clones.

The program listens to the clipboard and then saves them to text files.
When all the games are collected according to the config file
(by default in =~/.config/autowordle/games.yaml=),
then construct an image and put it into the clipboard.
Then save all the files into various archives.

This is very tailored to my personal use case
and may be difficult to use for others.
